aboutsummaryrefslogtreecommitdiff
path: root/engines/sword2/animation.cpp
diff options
context:
space:
mode:
authorJoost Peters2009-09-18 16:39:14 +0000
committerJoost Peters2009-09-18 16:39:14 +0000
commite1ad748f0d7802ea0e6772c14546117b75c60220 (patch)
tree782648d64b3aae6c9ef48c5f918007cc81173822 /engines/sword2/animation.cpp
parent066d748c95ca427eb60b140652e441e22a5f057a (diff)
downloadscummvm-rg350-e1ad748f0d7802ea0e6772c14546117b75c60220.tar.gz
scummvm-rg350-e1ad748f0d7802ea0e6772c14546117b75c60220.tar.bz2
scummvm-rg350-e1ad748f0d7802ea0e6772c14546117b75c60220.zip
SWORD2: Don't show a pop-up if the 'eye' movie is missing - it was omitted in later re-releases.
svn-id: r44187
Diffstat (limited to 'engines/sword2/animation.cpp')
-rw-r--r--engines/sword2/animation.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/engines/sword2/animation.cpp b/engines/sword2/animation.cpp
index 4a235315b6..b178bd23b6 100644
--- a/engines/sword2/animation.cpp
+++ b/engines/sword2/animation.cpp
@@ -337,9 +337,9 @@ MoviePlayer *makeMoviePlayer(const char *name, Sword2Engine *vm, Audio::Mixer *s
return NULL;
}
- // The demo tries to play some cutscenes that aren't there, so make
- // those warnings more discreet.
- if (!vm->_logic->readVar(DEMO)) {
+ // The demo tries to play some cutscenes that aren't there, so make those warnings more discreet.
+ // In addition, some of the later re-releases of the game don't have the "eye" Virgin logo movie.
+ if (!vm->_logic->readVar(DEMO) && strcmp(name, "eye") != 0) {
sprintf(buf, "Cutscene '%s' not found", name);
GUI::MessageDialog dialog(buf, "OK");
dialog.runModal();